Skip to contents

[Deprecated]

Use list_variables() instead to see available variables, or pass tables/indicators to compile_acs_data().

Usage

list_acs_variables(year = "2022", tables = NULL)

Arguments

year

The year for which variable names should be selected.

tables

An optional character vector of table names from the table registry (e.g., c("race", "snap")). When provided, only variables for the specified tables are returned. Use list_tables() to see available table names.

Value

NULL, invisibly. Previously returned a named vector of variable codes.

Examples

if (FALSE) { # \dontrun{
list_acs_variables()
} # }