Document variables from compile_acs_data()
generate_codebook.RdDefine how variables produced via urbnindicators::compile_acs_data()
are calculated.
Arguments
- .data
The dataset returned from
urbnindicators::compile_acs_data().- resolved_tables
A character vector of resolved table names from the table registry. When NULL (default), all registered tables are used.
- auto_table_entries
A list of auto-generated table entries from
build_auto_table_entry(). Default is an empty list.- user_definitions
A list of user-supplied DSL definition objects (e.g., from
define_percent()). Default is an empty list.
Value
A tibble containing the names and definitions of variables returned from
urbnindicators::compile_acs_data().
Details
Generates a tibble of variable names and definitions that describe how each variable was created.
Examples
if (FALSE) { # \dontrun{
df = compile_acs_data(
years = c(2024),
geography = "county",
states = "NJ",
counties = NULL,
spatial = FALSE) %>%
dplyr::select(-dplyr::matches("_M$"))
codebook = generate_codebook(.data = df)
} # }