Skip to contents

Define how variables produced via urbnindicators::compile_acs_data() are calculated.

Usage

generate_codebook(.data, resolved_tables = NULL)

Arguments

.data

The dataset returned from urbnindicators::compile_acs_data().

resolved_tables

A character vector of resolved table names from the table registry. When NULL (default), all registered tables are used.

Value

A tibble containing the names and definitions of variables returned from urbnindicators::compile_acs_data().

Details

Generates a tibble of variable names and definitions that describe how each variable was created.

Examples

if (FALSE) { # \dontrun{
df = compile_acs_data(
  years = c(2024),
  geography = "county",
  states = "NJ",
  counties = NULL,
  spatial = FALSE) %>%
  dplyr::select(-dplyr::matches("_M$|_SE$|_CV$"))
codebook = generate_codebook(.data = df)
} # }