Return ACS variables codes and names
list_acs_variables.RdUse list_variables() instead to see available variables, or pass
tables/indicators to compile_acs_data().
Arguments
- year
The year for which variable names should be selected.
- tables
An optional character vector of table names from the table registry (e.g.,
c("race", "snap")). When provided, only variables for the specified tables are returned. Uselist_tables()to see available table names.